@@ -39,9 +39,9 @@ import dateutil.tz
 import em
 import os
 import re
-import rospkg
 import sys
 import tempfile
+import traceback
 
 from pprint import pprint
 from subprocess import Popen, CalledProcessError
@@ -51,11 +51,13 @@ from ... util import execute_command
 from ... util import handle_global_arguments
 from ... util import bailout
 from ... util import ansi
+from ... util import print_exc
 # from . util import get_versions_from_upstream_tag
 from ... git import checkout
 from ... git import get_current_branch
 from ... git import track_branches
 from ... git import get_last_tag_by_date
+from ... git import show
 
 from ... logging import error
 from ... logging import info
@@ -74,6 +76,12 @@ except ImportError:
     print("rosdep was not detected, please install it.", file=sys.stderr)
     sys.exit(2)
 
+try:
+    import rospkg
+except ImportError:
+    print("rospkg was not detected, please install it.", file=sys.stderr)
+    sys.exit(3)
+
 '''
 The Debian binary package file names conform to the following convention:
 <foo>_<VersionNumber>-<DebianRevisionNumber>_<DebianArchitecture>.deb
@@ -285,7 +293,10 @@ def process_package_xml(args, directory=None):
     build_deps = (package.build_depends + package.buildtool_depends)
     data['BuildDepends'] = set([d.name for d in build_deps])
 
-    print("BuildDepends is %s for %s, from %s" % (data['BuildDepends'], package.name, xml_path))
+    print(
+        "BuildDepends is "
+        "%s for %s, from %s" % (data['BuildDepends'], package.name, xml_path)
+    )
 
     maintainers = []
     for m in package.maintainers:
@@ -333,12 +344,14 @@ def get_stack_data(args, directory=None):
             bailout("No stack.xml or package.xml found, exiting.")
 
 
-def expand(fname, stack_data, dest_dir, filetype=''):
+def expand(fname, stack_data, dest_dir, filetype='', custom=None):
     # insert template type
     if fname == 'rules' and stack_data['Catkin-DebRulesType'] == 'custom':
         path = os.path.join(dest_dir, '..', stack_data['Catkin-DebRulesFile'])
         with open(path, 'r') as f:
             file_em = f.read()
+    elif custom is not None:
+        file_em = custom
     else:
         if filetype != '':
             ifilename = (fname + '.' + filetype + '.em')
@@ -368,7 +381,6 @@ def find_deps(stack_data, apt_installer, rosdistro, debian_distro):
     deps = stack_data['Depends']
     build_deps = stack_data['BuildDepends']
 
-
     rosdep_view = rosdep2.catkin_support.get_catkin_view(rosdistro, os_name,
                                                          debian_distro,
                                                          update=False)
@@ -421,14 +433,21 @@ def generate_deb(stack_data, repo_path, stamp, rosdistro, debian_distro):
     expand('control', stack_data, dest_dir)
     expand('changelog', stack_data, dest_dir,
            filetype=stack_data['Catkin-ChangelogType'])
-    expand('rules', stack_data, dest_dir,
-           filetype=stack_data['Catkin-DebRulesType'])
+    override_rules = show('bloom', 'rules')
+    if override_rules is not None:
+        expand('rules', stack_data, dest_dir,
+               filetype=stack_data['Catkin-ChangelogType'],
+               custom=override_rules)
+    else:
+        expand('rules', stack_data, dest_dir,
+               filetype=stack_data['Catkin-DebRulesType'])
     # expand('copyright', stack_data, dest_dir,
            # filetype=stack_data['Catkin-CopyrightType'])
     # ofilename = os.path.join(dest_dir, 'copyright')
     # ofilestr = open(ofilename, "w")
     # print(stack_data['copyright'], file=ofilestr)
     # ofilestr.close()
+    expand('gbp.conf', stack_data, dest_dir)
 
     #compat to quiet warnings, 7 .. lucid
     ofilename = os.path.join(dest_dir, 'compat')
@@ -576,7 +595,13 @@ def main(sysargs=None):
         # update rosdep is needed
         if args.do_not_update_rosdep:
             info("Updating rosdep")
-            rosdep2.catkin_support.update_rosdep()
+            try:
+                rosdep2.catkin_support.update_rosdep()
+            except:
+                print_exc(traceback.format_exc())
+                error("Failed to update rosdep, did you run "
+                      "'rosdep init' first?")
+                return 1
         # do it
         result = execute_bloom_generate_debian(args, bloom_repo)
     finally:
